@@ -171,7 +171,8 @@
  * Standard include files will probably be ok.
  */
 
-#include <qstring.h>     /* for memset(), memcpy(), and memcmp() */
+//#include <QString>     /* for memset(), memcpy(), and memcmp() */
+#include <cstdlib>
 #include "twofish.h"
 
 
@@ -475,8 +476,8 @@
 #endif
 
 
-void Twofish_fatal(char* msg){
-	qCritical("Twofish: Fatal Error");
+void Twofish_fatal(const char* msg){
+	qCritical("Twofish: Fatal Error: %s",msg);
 	exit(1);
 }
 
